# Promissory Note

[![Build Status](https://travis-ci.com/flaviogf/promissory_note.svg?token=bkkT2qxAYSKVeVzJQpE7&branch=master)](https://travis-ci.com/flaviogf/promissory_note)
![GitHub](https://img.shields.io/github/license/flaviogf/promissory_note.svg)
![PyPI](https://img.shields.io/pypi/v/promissory-note.svg)

# Install

## Requirements

- python3.7 

## Installation with pip

```bash
pip install promissory-note
```

## Installation with git repository

```bash
git clone https://github.com/flaviogf/promissory_note.git
python setup.py build
python setup.py install
```

## Environment

```bash
export SEND_GRID_KEY
export FROM_EMAIL
```

## Usage
```bash
promissory-note-cli
```
